@@ -1,6 +1,6 @@
 mod api;
 mod channel;
-mod channel_binding;
+pub mod channel_binding;
 mod components;
 mod correlation_id;
 mod discriminator;
@@ -8,21 +8,21 @@ mod example;
 mod external_documentation;
 mod info;
 mod message;
-mod message_binding;
+pub mod message_binding;
 mod message_trait;
-mod operation_binding;
+pub mod operation_binding;
 mod operation_trait;
 mod parameter;
 mod reference;
-mod schema;
+pub mod schema;
 mod security_scheme;
 mod server;
-mod server_binding;
+pub mod server_binding;
 mod tag;
 mod variant_or;
 
 pub use api::AsyncAPI;
-pub use channel::Channel;
+pub use channel::{Channel, Operation};
 pub use channel_binding::ChannelBinding;
 pub use components::Components;
 pub use correlation_id::CorrelationId;
@@ -39,7 +39,7 @@ pub use parameter::Parameter;
 pub use reference::ReferenceOr;
 pub use schema::Schema;
 pub use security_scheme::SecurityScheme;
-pub use server::Server;
+pub use server::{SecurityRequirement, Server, ServerVariable};
 pub use server_binding::ServerBinding;
 pub use tag::Tag;
 pub use variant_or::{VariantOrUnknown, VariantOrUnknownOrEmpty};
